import argparse

from mjcf2urdf import convert_mjcf_to_urdf


def main():
    parser = argparse.ArgumentParser(
        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    parser.add_argument('input_mjcf', type=str,
                        help='MuJoCo xml file to be converted to URDF')
    parser.add_argument('--out', '-o', help='Output Directory Name',
                        default='result')
    args = parser.parse_args()

    convert_mjcf_to_urdf(args.input_mjcf, args.out)


if __name__ == '__main__':
    main()



import os
import six


def makedirs(name, mode=0o777, exist_ok=True):
    """An wrapper of os.makedirs that accepts exist_ok."""
    name = str(name)
    if six.PY2:
        try:
            os.makedirs(name, mode)
        except OSError:
            if not os.path.isdir(name):
                raise
    else:
        os.makedirs(name, mode, exist_ok=exist_ok)



import os.path as osp

import pybullet_utils.bullet_client as bulllet_client
import pybullet_utils.urdfEditor as urdfEditor

import mjcf2urdf


def convert_mjcf_to_urdf(input_mjcf, output_path):
    """Convert MuJoCo mjcf to URDF format and save.

    Parameters
    ----------
    input_mjcf : str
        input path of mjcf file.
    output_path : str
        output directory path of urdf.
    """
    client = bulllet_client.BulletClient()
    objs = client.loadMJCF(
        input_mjcf, flags=client.URDF_USE_IMPLICIT_CYLINDER)

    # create output directory
    mjcf2urdf.makedirs(output_path)

    for obj in objs:
        humanoid = objs[obj]
        ue = urdfEditor.UrdfEditor()
        ue.initializeFromBulletBody(humanoid, client._client)
        robot_name = str(client.getBodyInfo(obj)[1], 'utf-8')
        part_name = str(client.getBodyInfo(obj)[0], 'utf-8')
        save_visuals = False
        outpath = osp.join(
            output_path, "{}_{}.urdf".format(robot_name, part_name))
        ue.saveUrdf(outpath, save_visuals)
